==> bibo-1.0.0.tgz: package/debug.js <==
/**
 * List prompt example
 */

'use strict';
var inquirer = require('inquirer');
// var _ = require('lodash');

// inquirer.registerPrompt('autocomplete', require('inquirer-autocomplete-prompt'));

// var states = [
//   'Alabama',
//   'Alaska',
//   'American Samoa',
//   'Arizona',
//   'Arkansas',
//   'California',
//   'Colorado',
//   'Connecticut',
//   'Delaware',
//   'District Of Columbia',
//   'Federated States Of Micronesia',
//   'Florida',
//   'Georgia',
//   'Guam',
//   'Hawaii',
//   'Idaho',
//   'Illinois',
//   'Indiana',
//   'Iowa',
//   'Kansas',
//   'Kentucky',
//   'Louisiana',
//   'Maine',
//   'Marshall Islands',
//   'Maryland',
//   'Massachusetts',
//   'Michigan',
//   'Minnesota',
//   'Mississippi',
//   'Missouri',
//   'Montana',
//   'Nebraska',
//   'Nevada',
//   'New Hampshire',
//   'New Jersey',
//   'New Mexico',
//   'New York',
//   'North Carolina',
//   'North Dakota',
//   'Northern Mariana Islands',
//   'Ohio',
//   'Oklahoma',
//   'Oregon',
//   'Palau',
//   'Pennsylvania',
//   'Puerto Rico',
//   'Rhode Island',
//   'South Carolina',
//   'South Dakota',
//   'Tennessee',
//   'Texas',
//   'Utah',
//   'Vermont',
//   'Virgin Islands',
//   'Virginia',
//   'Washington',
//   'West Virginia',
//   'Wisconsin',
//   'Wyoming'
// ];

// function searchStates(answers, input) {
//   return new Promise(function(resolve) {


//       resolve(states.filter(function(state) {
//         return new RegExp('^' + input, 'i').exec(state) !== null;
//       }));

//   });
// }

// inquirer.prompt([{
//   type: 'autocomplete',
//   name: 'from',
//   message: 'Select a state to travel from',
//   source: searchStates
// }, {
//   type: 'autocomplete',
//   name: 'to',
//   message: 'Select a state to travel to',
//   source: searchStates
// }]).then(function(answers) {
//   console.log(JSON.stringify(answers, null, 2));
// })


// inquirer.prompt([
//   {
//     type: 'expand',
//     message: 'Conflict on `file.js`: ',
//     name: 'overwrite',
//     choices: [
//       {
//         key: 'y',
//         name: 'Overwrite',
//         value: 'overwrite'
//       },
//       {
//         key: 'a',
//         name: 'Overwrite this one and all next',
//         value: 'overwrite_all'
//       },
//       {
//         key: 'd',
//         name: 'Show diff',
//         value: 'diff'
//       },
//       new inquirer.Separator(),
//       {
//         key: 'x',
//         name: 'Abort',
//         value: 'abort'
//       }
//     ]
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });


inquirer.prompt([
  {
    type: 'checkbox',
    message: 'Select toppings',
    name: 'toppings',
    choices: [
      new inquirer.Separator(' = The Meats = '),
      {
        name: 'Pepperoni'
      },
      {
        name: 'Ham'
      },
      {
        name: 'Ground Meat'
      },
      {
        name: 'Bacon'
      },
      new inquirer.Separator(' = The Cheeses = '),
      {
        name: 'Mozzarella'
      },
      {
        name: 'Cheddar'
      },
      {
        name: 'Parmesan'
      },
      new inquirer.Separator(' = The usual ='),
      {
        name: 'Mushroom'
      },
      {
        name: 'Tomato'
      },
      new inquirer.Separator(' = The extras = '),
      {
        name: 'Pineapple'
      },
      {
        name: 'Olives',
        disabled: 'out of stock'
      },
      {
        name: 'Extra cheese'
      }
    ]
  }
]).then(function (answers) {
  console.log(JSON.stringify(answers, null, '  '));
});

// var choices = Array.apply(0, new Array(26)).map(function (x, y) {
//   return String.fromCharCode(y + 65);
// });
// choices.push('Multiline option \n  super cool feature');
// choices.push({
//   name: 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu. In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.',
//   value: 'foo',
//   short: 'The long option'
// });

// inquirer.prompt([
//   {
//     type: 'list',
//     name: 'letter',
//     message: 'What\'s your favorite letter?',
//     paginated: true,
//     choices: choices
//   },
//   {
//     type: 'checkbox',
//     name: 'name',
//     message: 'Select the letter contained in your name:',
//     paginated: true,
//     choices: choices
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });
//
//

// inquirer.prompt([
//   {
//     type: 'list',
//     name: 'theme',
//     message: 'What do you want to do?',
//     choices: [
//       'Order a pizza',
//       'Make a reservation',
//       new inquirer.Separator(),
//       'Ask for opening hours',
//       {
//         name: 'Contact support',
//         disabled: 'Unavailable at this time'
//       },
//       'Talk to the receptionist'
//     ]
//   },
//   {
//     type: 'list',
//     name: 'size',
//     message: 'What size do you need?',
//     choices: ['Jumbo', 'Large', 'Standard', 'Medium', 'Small', 'Micro'],
//     filter: function (val) {
//       return val.toLowerCase();
//     }
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });

// var nkw = require('npm-keyword');




// nkw('yeoman-generator').then(function (packages) {
//     console.log(packages.length);
//     packages.forEach(function (v) {
//         console.dir(v);
//         process.exit(1);
//     });
//     console.log(v.length);
// });

// var co = require('co');
// var choices = ['xx', '1', '2', '7'];
// var answer;

// inquirer.registerPrompt('autocomplete', require('inquirer-autocomplete-prompt'));

// co(function* () {
//     try {
//       answer = yield inquirer.prompt([{
//             type: 'autocomplete',
//             message: 'Enter the plugin to be installed',
//             name: 'plugin',
//             source: function (answers, input) {
//                 return new Promise(function (resolve, reject) {
//                     setTimeout(function () {
//                         resolve(choices.filter(function (v) {
//                             return new RegExp('^' + input, 'i').exec(v) != null;
//                         }));
//                     }, 50);

//                 });
//             }
//         }])
//     } catch (e) {
//         console.log(e);
//     }

// });

// console.log(answer);

// let spawn = require('cross-spawn');
// spawn('npm', ['install', '--save'], {
//     stdio: 'inherit'
// }).on('error', function (err) {
//     console.log(err);
// });
//
//
//

==> bibo-1.0.7.tgz: package/debug.js <==
/**
 * List prompt example
 */

'use strict';
var inquirer = require('inquirer');
// var _ = require('lodash');

// inquirer.registerPrompt('autocomplete', require('inquirer-autocomplete-prompt'));

// var states = [
//   'Alabama',
//   'Alaska',
//   'American Samoa',
//   'Arizona',
//   'Arkansas',
//   'California',
//   'Colorado',
//   'Connecticut',
//   'Delaware',
//   'District Of Columbia',
//   'Federated States Of Micronesia',
//   'Florida',
//   'Georgia',
//   'Guam',
//   'Hawaii',
//   'Idaho',
//   'Illinois',
//   'Indiana',
//   'Iowa',
//   'Kansas',
//   'Kentucky',
//   'Louisiana',
//   'Maine',
//   'Marshall Islands',
//   'Maryland',
//   'Massachusetts',
//   'Michigan',
//   'Minnesota',
//   'Mississippi',
//   'Missouri',
//   'Montana',
//   'Nebraska',
//   'Nevada',
//   'New Hampshire',
//   'New Jersey',
//   'New Mexico',
//   'New York',
//   'North Carolina',
//   'North Dakota',
//   'Northern Mariana Islands',
//   'Ohio',
//   'Oklahoma',
//   'Oregon',
//   'Palau',
//   'Pennsylvania',
//   'Puerto Rico',
//   'Rhode Island',
//   'South Carolina',
//   'South Dakota',
//   'Tennessee',
//   'Texas',
//   'Utah',
//   'Vermont',
//   'Virgin Islands',
//   'Virginia',
//   'Washington',
//   'West Virginia',
//   'Wisconsin',
//   'Wyoming'
// ];

// function searchStates(answers, input) {
//   return new Promise(function(resolve) {


//       resolve(states.filter(function(state) {
//         return new RegExp('^' + input, 'i').exec(state) !== null;
//       }));

//   });
// }

// inquirer.prompt([{
//   type: 'autocomplete',
//   name: 'from',
//   message: 'Select a state to travel from',
//   source: searchStates
// }, {
//   type: 'autocomplete',
//   name: 'to',
//   message: 'Select a state to travel to',
//   source: searchStates
// }]).then(function(answers) {
//   console.log(JSON.stringify(answers, null, 2));
// })


// inquirer.prompt([
//   {
//     type: 'expand',
//     message: 'Conflict on `file.js`: ',
//     name: 'overwrite',
//     choices: [
//       {
//         key: 'y',
//         name: 'Overwrite',
//         value: 'overwrite'
//       },
//       {
//         key: 'a',
//         name: 'Overwrite this one and all next',
//         value: 'overwrite_all'
//       },
//       {
//         key: 'd',
//         name: 'Show diff',
//         value: 'diff'
//       },
//       new inquirer.Separator(),
//       {
//         key: 'x',
//         name: 'Abort',
//         value: 'abort'
//       }
//     ]
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });


// inquirer.prompt([
//   {
//     type: 'checkbox',
//     message: 'Select toppings',
//     name: 'toppings',
//     choices: [
//       new inquirer.Separator(' = The Meats = '),
//       {
//         name: 'Pepperoni'
//       },
//       {
//         name: 'Ham'
//       },
//       {
//         name: 'Ground Meat'
//       },
//       {
//         name: 'Bacon'
//       },
//       new inquirer.Separator(' = The Cheeses = '),
//       {
//         name: 'Mozzarella'
//       },
//       {
//         name: 'Cheddar'
//       },
//       {
//         name: 'Parmesan'
//       },
//       new inquirer.Separator(' = The usual ='),
//       {
//         name: 'Mushroom'
//       },
//       {
//         name: 'Tomato'
//       },
//       new inquirer.Separator(' = The extras = '),
//       {
//         name: 'Pineapple'
//       },
//       {
//         name: 'Olives',
//         disabled: 'out of stock'
//       },
//       {
//         name: 'Extra cheese'
//       }
//     ]
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });

// var choices = Array.apply(0, new Array(26)).map(function (x, y) {
//   return String.fromCharCode(y + 65);
// });
// choices.push('Multiline option \n  super cool feature');
// choices.push({
//   name: 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Donec quam felis, ultricies nec, pellentesque eu, pretium quis, sem. Nulla consequat massa quis enim. Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu. In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.',
//   value: 'foo',
//   short: 'The long option'
// });

// inquirer.prompt([
//   {
//     type: 'list',
//     name: 'letter',
//     message: 'What\'s your favorite letter?',
//     paginated: true,
//     choices: choices
//   },
//   {
//     type: 'checkbox',
//     name: 'name',
//     message: 'Select the letter contained in your name:',
//     paginated: true,
//     choices: choices
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });
//
//

// inquirer.prompt([
//   {
//     type: 'list',
//     name: 'theme',
//     message: 'What do you want to do?',
//     choices: [
//       'Order a pizza',
//       'Make a reservation',
//       new inquirer.Separator(),
//       'Ask for opening hours',
//       {
//         name: 'Contact support',
//         disabled: 'Unavailable at this time'
//       },
//       'Talk to the receptionist'
//     ]
//   },
//   {
//     type: 'list',
//     name: 'size',
//     message: 'What size do you need?',
//     choices: ['Jumbo', 'Large', 'Standard', 'Medium', 'Small', 'Micro'],
//     filter: function (val) {
//       return val.toLowerCase();
//     }
//   }
// ]).then(function (answers) {
//   console.log(JSON.stringify(answers, null, '  '));
// });

// var nkw = require('npm-keyword');




// nkw('yeoman-generator').then(function (packages) {
//     console.log(packages.length);
//     packages.forEach(function (v) {
//         console.dir(v);
//         process.exit(1);
//     });
//     console.log(v.length);
// });

// var co = require('co');
// var choices = ['xx', '1', '2', '7'];
// var answer;

// inquirer.registerPrompt('autocomplete', require('inquirer-autocomplete-prompt'));

// co(function* () {
//     try {
//       answer = yield inquirer.prompt([{
//             type: 'autocomplete',
//             message: 'Enter the plugin to be installed',
//             name: 'plugin',
//             source: function (answers, input) {
//                 return new Promise(function (resolve, reject) {
//                     setTimeout(function () {
//                         resolve(choices.filter(function (v) {
//                             return new RegExp('^' + input, 'i').exec(v) != null;
//                         }));
//                     }, 50);

//                 });
//             }
//         }])
//     } catch (e) {
//         console.log(e);
//     }

// });

// console.log(answer);

// let spawn = require('cross-spawn');
// spawn('npm', ['install', '--save'], {
//     stdio: 'inherit'
// }).on('error', function (err) {
//     console.log(err);
// });
//
//
//
var globby = require('globby');

console.log(globby.sync(['**/*.psd'], {
  cwd: process.cwd()
}));
